@@ -2,7 +2,7 @@ from pathlib import Path
 from typing import List
 
 from pyconverters_grobid.grobid import GrobidConverter, GrobidParameters
-from pymultirole_plugins.v1.schema import Document
+from pymultirole_plugins.v1.schema import Document, DocumentList
 from starlette.datastructures import UploadFile
 
 
@@ -10,13 +10,19 @@ def test_grobid_xml():
     converter = GrobidConverter()
     parameters = GrobidParameters(sentences=True, citations=True)
     testdir = Path(__file__).parent
-    source = Path(testdir, 'data/PMC1636350.pdf')
+    source = Path(testdir, "data/PMC1636350.pdf")
     with source.open("rb") as fin:
-        docs: List[Document] = converter.convert(UploadFile(source.name, fin, 'application/pdf'), parameters)
+        docs: List[Document] = converter.convert(
+            UploadFile(source.name, fin, "application/pdf"), parameters
+        )
     assert len(docs) == 1
     assert docs[0].identifier
     assert docs[0].text
     assert docs[0].title
-    assert 'TITLE' in docs[0].boundaries
+    assert "TITLE" in docs[0].boundaries
     assert docs[0].annotations
     assert len(docs[0].annotations[0].terms) == 1
+    json_file = source.with_suffix(".json")
+    dl = DocumentList(__root__=docs)
+    with json_file.open("w") as fout:
+        print(dl.json(exclude_none=True, exclude_unset=True, indent=2), file=fout)
